==> haskell-xcffib-0.5.1-48-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xcffib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xcffib
version: 0.5.1
id: xcffib-0.5.1-C0FbPaO8SQ3Do8O9mAglpK
key: xcffib-0.5.1-C0FbPaO8SQ3Do8O9mAglpK
license: OtherLicense
maintainer: Tycho Andersen <tycho@tycho.ws>
homepage: http://github.com/tych0/xcffib
synopsis: A cffi-based python binding for X
description:
    A cffi-based python binding for X, comparable to xpyb
category: X11
author: Tycho Andersen
exposed: True
indefinite: False
exposed-modules:
    Data.XCB.Python.Parse Data.XCB.Python.PyHelpers
abi: 4efc036f0a3bd55669d6f5aa56d2f30b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/xcffib-0.5.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/xcffib-0.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/xcffib-0.5.1
hs-libraries: HSxcffib-0.5.1-C0FbPaO8SQ3Do8O9mAglpK
depends:
    base-4.10.1.0 xcb-types-0.8.0-2Ku92yCYNyIG7ZaknHxybk
    language-python-0.5.4-8C5yVPTZS4cEoKsquoNSKR filepath-1.4.1.2
    filemanip-0.3.6.3-9giY7J5s1R0FqQX715Wz4K
    split-0.2.3.2-7cayvoeRj5XIrIBUB58mMy containers-0.5.10.2
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    attoparsec-0.13.2.0-1AORA640dG8HmlrlyiwzkH bytestring-0.10.8.2
    either-5-8C0CQhohxnUI5Cisu0Hdr3
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             xcb-types-0.8.0-2Ku92yCYNyIG7ZaknHxybk=2f1ee033cc5571e82c7ba03eb04e7a01
             language-python-0.5.4-8C5yVPTZS4cEoKsquoNSKR=19f4ce4cb77c7ef0e4bf37206141ee99
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             filemanip-0.3.6.3-9giY7J5s1R0FqQX715Wz4K=7a61c72fbd9b5fa3b8379413a510575e
             split-0.2.3.2-7cayvoeRj5XIrIBUB58mMy=614819b9f074e058df73dc3c520cf25f
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=1e76d6f7019a4b5c8c222b2fbbb06681
             attoparsec-0.13.2.0-1AORA640dG8HmlrlyiwzkH=1e5250700950658eff033f7537304029
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             either-5-8C0CQhohxnUI5Cisu0Hdr3=0677aa69dba78e9d231b71e329f4f330
haddock-interfaces: /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html: /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xcffib-0.5.1-49-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xcffib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xcffib
version: 0.5.1
id: xcffib-0.5.1-4Ox78cLLk0q6Fcb9JL3h64
key: xcffib-0.5.1-4Ox78cLLk0q6Fcb9JL3h64
license: OtherLicense
maintainer: Tycho Andersen <tycho@tycho.ws>
homepage: http://github.com/tych0/xcffib
synopsis: A cffi-based python binding for X
description:
    A cffi-based python binding for X, comparable to xpyb
category: X11
author: Tycho Andersen
exposed: True
indefinite: False
exposed-modules:
    Data.XCB.Python.Parse Data.XCB.Python.PyHelpers
abi: 955ded486d09fef1aa2ec379bfff4bef
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/xcffib-0.5.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/xcffib-0.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/xcffib-0.5.1
hs-libraries: HSxcffib-0.5.1-4Ox78cLLk0q6Fcb9JL3h64
depends:
    base-4.10.1.0 xcb-types-0.8.0-EzQQ4fyUfFR477WE3O83cV
    language-python-0.5.4-8C5yVPTZS4cEoKsquoNSKR filepath-1.4.1.2
    filemanip-0.3.6.3-9giY7J5s1R0FqQX715Wz4K
    split-0.2.3.2-7cayvoeRj5XIrIBUB58mMy containers-0.5.10.2
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    attoparsec-0.13.2.0-GogCtb3ELCcCdy2SawxAmT bytestring-0.10.8.2
    either-5-I3NHfRCWwZB9WJ7CtLsffd
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             xcb-types-0.8.0-EzQQ4fyUfFR477WE3O83cV=ff42c1c2e96246dc4969ed7dc409f223
             language-python-0.5.4-8C5yVPTZS4cEoKsquoNSKR=19f4ce4cb77c7ef0e4bf37206141ee99
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             filemanip-0.3.6.3-9giY7J5s1R0FqQX715Wz4K=7a61c72fbd9b5fa3b8379413a510575e
             split-0.2.3.2-7cayvoeRj5XIrIBUB58mMy=614819b9f074e058df73dc3c520cf25f
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=1e76d6f7019a4b5c8c222b2fbbb06681
             attoparsec-0.13.2.0-GogCtb3ELCcCdy2SawxAmT=969f51e12ac15d411e4c04135fb32864
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             either-5-I3NHfRCWwZB9WJ7CtLsffd=b5d85a1e5c747a4091a3a56efa19d6dc
haddock-interfaces: /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html: /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
